#!/usr/bin/env python
from __future__ import division

import os,sys
import nose
from nose import *

from refcore import delivery
from refcore import report
from refcore import transfer
from refcore import deliverCDBS
from refcore import error
from refcore import helper

startdir = os.path.abspath(os.path.curdir)

def setup_func():
    # Generic setup function
    thisdir = os.path.dirname(os.path.abspath(__file__))
    os.chdir(thisdir)

def teardown_func():
    # Generic teardown function
    os.chdir(startdir)

@with_setup(setup_func,teardown_func)
def test():
    # Generic test
    assert True

@with_setup(setup_func,teardown_func)
def test_check_headers_fail():
    try:
        delivery.check_headers("alpha_lyr_stis_003.fits")
    except error.CDBSError:
        return
    assert False

@with_setup(setup_func,teardown_func)
def test_check_headers_pass():
    delivery.check_headers("alpha_lyr_stis_003_fixed.fits")


@with_setup(setup_func,teardown_func)
def test_check_FITS_standard_pass():
    delivery.check_FITS_standard("j8bt06nyq_flt.fits")

@with_setup(setup_func,teardown_func)
def test_check_FITS_standard_fail():
    try:
        delivery.check_FITS_standard("s940253nj_mdz.fits")
    except error.CDBSError:
        return
    assert False

@with_setup(setup_func,teardown_func)
def test_certify_pass():
    delivery.CDBS_certify("s940253nj_mdz.fits")

@with_setup(setup_func,teardown_func)
def test_certify_image_pass():
    delivery.CDBS_certify("n9h2102ji_lin.fits")

@with_setup(setup_func,teardown_func)
def test_certify_fail():
    try:
        delivery.CDBS_certify("j8bt06nyq_flt.fits")
    except error.CDBSError:
        return
    assert False

@with_setup(setup_func,teardown_func)
def test_create_load_file():
    delivery.create_load_file("alpha_lyr_stis_003_fixed.fits")
    if helper.asciifilesmatch("alpha_lyr_stis_003_fixed.lod",
                              "ref_alpha_lyr_stis_003_fixed.lod"):
        os.remove("alpha_lyr_003_fixed.lod")
        return
    os.remove("alpha_lyr_003_fixed.lod")
    assert False

@with_setup(setup_func,teardown_func)
def test_populate_load_file():
    delivery.populate_load_file("alpha_lyr_stis_003_fixed.fits",
                                "ref_alpha_lyr_stis_003_fixed.lod",comments=True, 
                                change_level="",opus_flag='Y', 
                                pedigree="", log=None)
    if helper.asciifilesmatch("populated_alpha_lyr_stis_003_fixed.lod",
                              "pop_ref_alpha_lyr_stis_003_fixed.lod"):
        os.remove("pop_ref_alpha_lyr_stis_003_fixed.lod")
        return
    os.remove("pop_ref_alpha_lyr_stis_003_fixed.lod")
    assert False
